/*******************************************************************************
*            Programme de commande Sepcsmaster                                 *
*            d'aprs ManufacturingTest (PLX Technology)                        *
*                                                                              *
*       Cration : 7 juillet 2003                                              *
*                  C.Pailler               LAL Orsay                           *
 ******************************************************************************/

/**********************************************************************
 *                                                                    *
 * Module Name:                                                       *
 *                                                                    *
 *     PlxInitialize.c                                                *
 *                                                                    *
 * Abstract:                                                          *
 *                                                                    *
 *     This module supports detection of mulitple PLX devices.        *
 *                                                                    *
 * Revision History:                                                  *
 *     02-15-00 : Modified to support PCI9030                         *
 *     07-22-99 : Modified to support IOP480                          *
 *     09-04-98 : Modified to support 9054 hot swap                   *
 *     07-09-98 : Support for SDK 2.0                                 *
 *     10-07-97 : Modified to support IOP programs                    *
 *     09-25-97 : Created                                             *
 *                                                                    *
 *********************************************************************/
//#include "StdAfx.h"
#include "PlxInit.h"

//#define  PLX_PCI9050RDK_DEVICE_ID  0x9050

U32 FindDevice(HANDLE *drvHandle, DEVICE_LIST *DeviceList)
{
	U32             TotalDeviceNum;
	U32             DeviceNum;
    RETURN_CODE     rc;
	DEVICE_LOCATION device;

	TotalDeviceNum = FIND_AMOUNT_MATCHED;

	device.BusNumber = MINUS_ONE_LONG;
	device.SlotNumber = MINUS_ONE_LONG;
	device.VendorId = MINUS_ONE_LONG;
	device.DeviceId = MINUS_ONE_LONG;
	device.SerialNumber[0] = '\0';

	if ((rc = PlxPciDeviceFind(&device, &TotalDeviceNum)) != ApiSuccess)
	{
		printf("Not working\n");
		return 0;
	}
	else
	{
		for (DeviceNum = 0; DeviceNum < TotalDeviceNum; DeviceNum++)
		{
			device.BusNumber = MINUS_ONE_LONG;
	        device.SlotNumber = MINUS_ONE_LONG;
	        device.VendorId = MINUS_ONE_LONG;
 	        device.DeviceId = MINUS_ONE_LONG;
	        device.SerialNumber[0] = '\0';

			PlxPciDeviceFind(&device, &DeviceNum);
			sprintf(DeviceList[DeviceNum].DevStr, 
				    "DeviceID  %.4x  VendorID  %.4x   Slot %.2x  Bus %.2x", 
					device.DeviceId,
					device.VendorId,
					device.SlotNumber,
					device.BusNumber);
			DeviceList[DeviceNum].device.DeviceId   = device.DeviceId;
            DeviceList[DeviceNum].device.VendorId   = device.VendorId;
            DeviceList[DeviceNum].device.SlotNumber = device.SlotNumber;
            DeviceList[DeviceNum].device.BusNumber  = device.BusNumber;

		}
        return DeviceNum;		
	}

}


/*****************************************************
*   Procedure:  SelectDevices
*   Abstract :  Asks the user which PLX device to use
*   Arguments:  drvHandle, handle of the PCI device
*               device,    pointer to device selected
*   Returns  :  Total Plx devices found
*               -1,  if user cancelled the selection
******************************************************/
char SelectDevice(HANDLE *drvHandle, DEVICE_LIST *DeviceList)
{
    U8              slot, bus;
    U8              deviceNum;
    U32             regData;
    RETURN_CODE     rc;
   
    deviceNum = 0;
    /* Search for PLX Devices */
    for (bus=0; bus <=3; bus++)
    {
        for (slot=0; slot<MAX_PCI_DEV; slot++)
        {
            regData = PlxPciConfigRegisterRead(bus, slot, 0, &rc); //Read first pci config register

            if (regData != 0xFFFFFFFF && IsPlxDevice(regData))
            {
//                sprintf(DeviceList[deviceNum].DevStr, "DeviceID  %.4x  VendorID  %.4x   Slot %.2x  Bus %.2x", regData>>16, regData&0xFFFF, slot, bus);
                sprintf(DeviceList[deviceNum].DevStr, "Slot %.2x  Bus %.2x", slot, bus);
                DeviceList[deviceNum].device.DeviceId   = (regData>>16) & 0xFFFF;
                DeviceList[deviceNum].device.VendorId   = regData & 0xFFFF;
                DeviceList[deviceNum].device.SlotNumber = slot;
                DeviceList[deviceNum].device.BusNumber  = bus;
                deviceNum++;
            }
        }
    }

    return deviceNum;
}


/**************************************************************
*   Procedure:  IsPlxDevice
*   Abstract :  Adds a device to a list of devices
*   Arguments:  DevVenId, the Device & Vendor ID register value
*   Returns  :  TRUE, if PLX device
*               FALSE, if not a recognized PLX device
***************************************************************/

BOOLEAN IsPlxDevice(U32 DevVenId)
{
    switch (DevVenId)
    {
        /* PLX 401B */
        //case ((PLX_9080RDK_401_DEVICE_ID<<16) | PLX_VENDOR_ID):

        /* MPC 860 */
        //case ((PLX_9080RDK_860_DEVICE_ID<<16) | PLX_VENDOR_ID):

        /* IBM 401 */
        //case ((PLX_9080RDK_401_DEVICE_ID<<16) | IBM_VENDOR_ID):

        /* Intel i960 */
        //case ((PLX_9080RDK_960_DEVICE_ID<<16) | PLX_VENDOR_ID):

        /* PLX Generic */
        //case (((ULONG)PLX_9080_DEVICE_ID<<16) | PLX_VENDOR_ID):

	    /* PCI 9054 RDK */
//	    case ((PLX_9054RDK_860_DEVICE_ID<<16) | PLX_VENDOR_ID):
        /* CPCI 9054 RDK */
//        case ((PLX_CPCI9054RDK_860_DEVICE_ID<<16) | PLX_VENDOR_ID):
        /* IOP480 RDK */
//        case ((PLX_IOP480RDK_DEVICE_ID<<16) | PLX_VENDOR_ID):
        /* PCI 9054-LITE */
//        case ((PLX_9054RDK_LITE_DEVICE_ID<<16) | PLX_VENDOR_ID):
/**********************************************************/
/*ajout : CP 3 avril 2003    LAL Orsay*/
		/* PCI 9030 */
        case ((PLX_9030_DEVICE_ID<<16) | PLX_VENDOR_ID):
/**********************************************************/
		/* PCI 9030 RDK */
//        case ((PLX_9030RDK_LITE_DEVICE_ID<<16) | PLX_VENDOR_ID):
		/* CompactPCI 9030 RDK */
//        case ((PLX_CPCI9030RDK_LITE_DEVICE_ID<<16) | PLX_VENDOR_ID):
		/*PCI 9050 RDK */
//		case (PLX_PCI9050RDK_DEVICE_ID<<16 | PLX_VENDOR_ID):

        return TRUE;
    }

    return FALSE;
}

