#ifndef __PLX_H
#define __PLX_H

/*******************************************************************************
 * Copyright (c) 2001 PLX Technology, Inc.
 * 
 * PLX Technology Inc. licenses this software under specific terms and
 * conditions.  Use of any of the software or derviatives thereof in any
 * product without a PLX Technology chip is strictly prohibited. 
 * 
 * PLX Technology, Inc. provides this software AS IS, WITHOUT ANY WARRANTY,
 * EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, ANY WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  PLX makes no guarantee
 * or representations regarding the use of, or the results of the use of,
 * the software and documentation in terms of correctness, accuracy,
 * reliability, currentness, or otherwise; and you rely on the software,
 * documentation and results solely at your own risk.
 * 
 * IN NO EVENT SHALL PLX BE LIABLE FOR ANY LOSS OF USE, LOSS OF BUSINESS,
 * LOSS OF PROFITS, INDIRECT, INCIDENTAL, SPECIAL OR CONSEQUENTIAL DAMAGES
 * OF ANY KIND.  IN NO EVENT SHALL PLX'S TOTAL LIABILITY EXCEED THE SUM
 * PAID TO PLX FOR THE PRODUCT LICENSED HEREUNDER.
 * 
 ******************************************************************************/

/******************************************************************************
 *
 * File Name:
 *
 *      Plx.h
 *
 * Description:
 *
 *      This file contains definitions that are common to all PCI SDK code.
 *
 * Revision:
 *
 *      05-31-01 : PCI SDK v3.30
 *
 ******************************************************************************/


#ifdef __cplusplus
extern "C" {
#endif




/**********************************************
*               Definitions
**********************************************/
/* Define the max number of PCI buses and slots */
#define MAX_PCI_BUS                      32
#define MAX_PCI_DEV                      32

/* Define the valid vendor IDs */
#define NO_VENDOR_ID                     0xFFFF
#define PLX_VENDOR_ID                    0x10B5

/* Define the valid device IDs */
#define NO_DEVICE_ID                     0xFFFF
//#define PLX_9050_DEVICE_ID               0x9050
#define PLX_9030_DEVICE_ID               0x9030
//#define PLX_9060_DEVICE_ID               0x9060
//#define PLX_9080_DEVICE_ID               0x9080
//#define PLX_9054_DEVICE_ID               0x9054
//#define PLX_9056_DEVICE_ID               0x9056
//#define PLX_9656_DEVICE_ID               0x9656
//#define PLX_480_DEVICE_ID                0x0480

/* Define the evaluation board device IDs */
/*#define PLX_9080RDK_960_DEVICE_ID        0x0960
#define PLX_9080RDK_401B_DEVICE_ID       0x0401
#define PLX_9080RDK_860_DEVICE_ID        0x0860
#define PLX_9054RDK_860_DEVICE_ID        0x1860
#define PLX_9054RDK_LITE_DEVICE_ID       0x5406
#define PLX_CPCI9054RDK_860_DEVICE_ID    0xC860
#define PLX_9056RDK_LITE_DEVICE_ID       0x5601
#define PLX_9056RDK_860_DEVICE_ID        0x56c2
#define PLX_9656RDK_LITE_DEVICE_ID       0x9601
#define PLX_9656RDK_860_DEVICE_ID        0x96c2
#define PLX_IOP480RDK_DEVICE_ID          0x0480
#define PLX_9030RDK_LITE_DEVICE_ID       0x3001
#define PLX_CPCI9030RDK_LITE_DEVICE_ID   0x30c1
#define PLX_9050RDK_LITE_DEVICE_ID       0x9050
#define PLX_9052RDK_LITE_DEVICE_ID       0x5201*/

// New Capabilities flags
#define CAPABILITY_POWER_MANAGEMENT      (1 << 0)
#define CAPABILITY_HOT_SWAP              (1 << 1)
#define CAPABILITY_VPD                   (1 << 2)

/* The local CPU will reset when this value is written to the doorbell */
#define PLX_RESET_EMBED_INT              ((unsigned long)(1 << 31))

/* Define a large value for a signal to the driver */
#define FIND_AMOUNT_MATCHED              80001

/* Define -1 values for the different types */
#define MINUS_ONE_LONG                   0xFFFFFFFFL
#define MINUS_ONE_SHORT                  0xFFFF
#define MINUS_ONE_CHAR                   0xFF

/*
 * The value for BLOCK_SIZE is standard for IBM image files and therfore 
 * should not be modified.
 */
#define BLOCK_SIZE                       512

/* Constants for Big-Endian 32-bit bit positions */
#define BE_U32_BIT0             0x80000000
#define BE_U32_BIT1             0x40000000
#define BE_U32_BIT2             0x20000000
#define BE_U32_BIT3             0x10000000
#define BE_U32_BIT4             0x08000000
#define BE_U32_BIT5             0x04000000
#define BE_U32_BIT6             0x02000000
#define BE_U32_BIT7             0x01000000
#define BE_U32_BIT8             0x00800000
#define BE_U32_BIT9             0x00400000
#define BE_U32_BIT10            0x00200000
#define BE_U32_BIT11            0x00100000
#define BE_U32_BIT12            0x00080000
#define BE_U32_BIT13            0x00040000
#define BE_U32_BIT14            0x00020000
#define BE_U32_BIT15            0x00010000
#define BE_U32_BIT16            0x00008000
#define BE_U32_BIT17            0x00004000
#define BE_U32_BIT18            0x00002000
#define BE_U32_BIT19            0x00001000
#define BE_U32_BIT20            0x00000800
#define BE_U32_BIT21            0x00000400
#define BE_U32_BIT22            0x00000200
#define BE_U32_BIT23            0x00000100
#define BE_U32_BIT24            0x00000080
#define BE_U32_BIT25            0x00000040
#define BE_U32_BIT26            0x00000020
#define BE_U32_BIT27            0x00000010
#define BE_U32_BIT28            0x00000008
#define BE_U32_BIT29            0x00000004
#define BE_U32_BIT30            0x00000002
#define BE_U32_BIT31            0x00000001


/* Constants for 16-bit bit positions */
#define BE_U16_BIT0             0x8000
#define BE_U16_BIT1             0x4000
#define BE_U16_BIT2             0x2000
#define BE_U16_BIT3             0x1000
#define BE_U16_BIT4             0x0800
#define BE_U16_BIT5             0x0400
#define BE_U16_BIT6             0x0200
#define BE_U16_BIT7             0x0100
#define BE_U16_BIT8             0x0080
#define BE_U16_BIT9             0x0040
#define BE_U16_BIT10            0x0020
#define BE_U16_BIT11            0x0010
#define BE_U16_BIT12            0x0008
#define BE_U16_BIT13            0x0004
#define BE_U16_BIT14            0x0002
#define BE_U16_BIT15            0x0001


/* Constants for 8-bit bit positions */
#define BE_U8_BIT0              0x80
#define BE_U8_BIT1              0x40
#define BE_U8_BIT2              0x20
#define BE_U8_BIT3              0x10
#define BE_U8_BIT4              0x08
#define BE_U8_BIT5              0x04
#define BE_U8_BIT6              0x02
#define BE_U8_BIT7              0x01




#ifdef __cplusplus
}
#endif

#endif
