#ifndef __PLX_IOCTL_H
#define __PLX_IOCTL_H

/*******************************************************************************
 * Copyright (c) 2001 PLX Technology, Inc.
 *
 * PLX Technology Inc. licenses this software under specific terms and
 * conditions.  Use of any of the software or derviatives thereof in any
 * product without a PLX Technology chip is strictly prohibited.
 *
 * PLX Technology, Inc. provides this software AS IS, WITHOUT ANY WARRANTY,
 * EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, ANY WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  PLX makes no guarantee
 * or representations regarding the use of, or the results of the use of,
 * the software and documentation in terms of correctness, accuracy,
 * reliability, currentness, or otherwise; and you rely on the software,
 * documentation and results solely at your own risk.
 *
 * IN NO EVENT SHALL PLX BE LIABLE FOR ANY LOSS OF USE, LOSS OF BUSINESS,
 * LOSS OF PROFITS, INDIRECT, INCIDENTAL, SPECIAL OR CONSEQUENTIAL DAMAGES
 * OF ANY KIND.  IN NO EVENT SHALL PLX'S TOTAL LIABILITY EXCEED THE SUM
 * PAID TO PLX FOR THE PRODUCT LICENSED HEREUNDER.
 *
 ******************************************************************************/

/******************************************************************************
 *
 * File Name:
 *
 *      PlxIoctl.h
 *
 * Description:
 *
 *      This file contains the common I/O Control messages shared between
 *      the driver and the PCI API.
 *
 * Revision History:
 *
 *      01-30-01 : PCI SDK v3.20
 *
 ******************************************************************************/


#ifdef __cplusplus
extern "C" {
#endif

#include "PlxTypes.h"




/* Device Management functions parameters */
typedef struct _MANAGEMENTDATA
{
    RETURN_CODE         ReturnCode;
    U32                 CfgRegNumber;
    U32                 Value;
    DEVICE_LOCATION     Device;
    VIRTUAL_ADDRESSES   VirtAddr;
    HANDLE              UserProcessId;
    PCI_MEMORY          PciMemory;
} MANAGEMENTDATA;


/* Register Operations parameters */
typedef struct _REGISTERDATA
{
    RETURN_CODE  ReturnCode;
    U32          RegOffset;
    U32          Count;
    U32          Data;
    MAILBOX_ID   MailboxId;
} REGISTERDATA;


/*  Bus Memory and IOP transactions parameters */
typedef struct _BUSIOPDATA
{
    RETURN_CODE  ReturnCode;
    IOP_SPACE    IopSpace;
    U32          Address;
    BOOLEAN      Remap;
    U32          Data;
    U32          TransferSize;
    ACCESS_TYPE  AccessType;
    U8           ByteBuffer;
    U16          ShortBuffer;
    U32          LongBuffer;
} BUSIOPDATA;


/* DMA transaction parameters */
typedef struct _DMADATA
{
    RETURN_CODE             ReturnCode;
    U32                     SourceAddrs;
    U32                     DestAddrs;
    U32                     TransferSize;
    DMA_TRANSFER_ELEMENT    TransBlock1;
    DMA_CHANNEL_DESC        DmaChannelDesc;
    DMA_CHANNEL             DmaChannel;
    DMA_DIRECTION           DmaDirection;
    DMA_COMMAND             DmaCommand;
    BOOLEAN                 ReturnImmediate;
} DMADATA;


/* This structure will hold all other datatypes */
typedef struct _MISCDATA
{
    PLX_INTR        IntrInfo;
    U32             Value1;
    U32             Value2;
    U32             Value;
    PLX_POWER_LEVEL PlxPowerLevel;
    EEPROM_TYPE     EepromType;
    USER_PIN        UserPinNum;
    PLX_PIN_STATE   PinState;
    RETURN_CODE     ReturnCode;
    HANDLE          EventHandle;
} MISCDATA;


/*  Used to pass all arguments down to the driver */
typedef union _IOCTLDATA
{
    MANAGEMENTDATA MgmtData;
    REGISTERDATA   RegData;
    BUSIOPDATA     BusIopData;
    DMADATA        DmaData;
    MISCDATA       MiscData;
} IOCTLDATA;


/****************************************************************
 * The DeviceType field of the CTL_CODE is kept to the old
 * definition for compatibility reasons.  The next SDK release
 * may change this to a Microsoft defined type.
 ***************************************************************/
// #define FILE_DEVICE_PLX                         FILE_DEVICE_UNKNOWN
#define FILE_DEVICE_PLX                         0x00008300   // Legacy definition

#define IOCTL_MSG( code )                       CTL_CODE(             \
                                                    FILE_DEVICE_PLX,  \
                                                    code,             \
                                                    METHOD_BUFFERED,  \
                                                    FILE_ANY_ACCESS   \
                                                    )

/*
 *  Macro definition for IOCTL control codes.
 *
 *  Note: Codes 0-2047 (0-7ffh) are reserved by Microsoft
 *        Code 2048-4095 are reserved for OEMs
 */

#define PLX_IOCTL_DEVICE_INIT                   IOCTL_MSG( 0x808 )
#define PLX_IOCTL_PCI_DEVICE_FIND               IOCTL_MSG( 0x803 )
#define PLX_IOCTL_SEARCH_PCI_BUS                IOCTL_MSG( 0x804 )

#define PLX_IOCTL_DRIVER_VERSION                IOCTL_MSG( 0x8d0 )
#define PLX_IOCTL_CHIP_TYPE_GET                 IOCTL_MSG( 0x8d1 )
#define PLX_IOCTL_PCI_BOARD_RESET               IOCTL_MSG( 0x8d2 )

#define PLX_IOCTL_BASE_ADDRESSES_GET            IOCTL_MSG( 0x805 )
#define PLX_IOCTL_BASE_ADDRESSES_FREE           IOCTL_MSG( 0x806 )
#define PLX_IOCTL_BAR_RANGE_GET                 IOCTL_MSG( 0x807 )

#define PLX_IOCTL_COMMON_BUFFER_GET             IOCTL_MSG( 0x809 )
#define PLX_IOCTL_COMMON_BUFFER_FREE            IOCTL_MSG( 0x80a )

#define PLX_IOCTL_CONFIG_REGISTER_READ          IOCTL_MSG( 0x800 )
#define PLX_IOCTL_CONFIG_REGISTER_WRITE         IOCTL_MSG( 0x801 )
#define PLX_IOCTL_CONFIG_REGISTER_READ_ALL      IOCTL_MSG( 0x802 )

#define PLX_IOCTL_REGISTER_READ                 IOCTL_MSG( 0x820 )
#define PLX_IOCTL_REGISTER_WRITE                IOCTL_MSG( 0x821 )
#define PLX_IOCTL_REGISTER_READ_ALL             IOCTL_MSG( 0x822 )

#define PLX_IOCTL_INTR_ENABLE                   IOCTL_MSG( 0x832 )
#define PLX_IOCTL_INTR_DISABLE                  IOCTL_MSG( 0x833 )
#define PLX_IOCTL_INTR_ATTACH                   IOCTL_MSG( 0x830 )
#define PLX_IOCTL_INTR_DETACH                   IOCTL_MSG( 0x831 )
#define PLX_IOCTL_INTR_STATUS_GET               IOCTL_MSG( 0x834 )

#define PLX_IOCTL_BUS_IOP_READ                  IOCTL_MSG( 0x840 )
#define PLX_IOCTL_BUS_IOP_WRITE                 IOCTL_MSG( 0x841 )
#define PLX_IOCTL_IO_PORT_READ                  IOCTL_MSG( 0x842 )
#define PLX_IOCTL_IO_PORT_WRITE                 IOCTL_MSG( 0x843 )

#define PLX_IOCTL_POWER_LEVEL_SET               IOCTL_MSG( 0x880 )
#define PLX_IOCTL_POWER_LEVEL_GET               IOCTL_MSG( 0x881 )
#define PLX_IOCTL_PM_ID_READ                    IOCTL_MSG( 0x8c8 )
#define PLX_IOCTL_PM_NCP_READ                   IOCTL_MSG( 0x8c9 )

#define PLX_IOCTL_HS_ID_READ                    IOCTL_MSG( 0x8c2 )
#define PLX_IOCTL_HS_NCP_READ                   IOCTL_MSG( 0x8c3 )
#define PLX_IOCTL_HS_STATUS                     IOCTL_MSG( 0x8c4 )

#define PLX_IOCTL_VPD_ID_READ                   IOCTL_MSG( 0x8ca )
#define PLX_IOCTL_VPD_NCP_READ                  IOCTL_MSG( 0x8cb )
#define PLX_IOCTL_VPD_READ                      IOCTL_MSG( 0x8cd )
#define PLX_IOCTL_VPD_WRITE                     IOCTL_MSG( 0x8ce )

#define PLX_IOCTL_EEPROM_PRESENT                IOCTL_MSG( 0x8cc )
#define PLX_IOCTL_SERIAL_EEPROM_READ            IOCTL_MSG( 0x882 )
#define PLX_IOCTL_SERIAL_EEPROM_READ_BY_OFFSET  IOCTL_MSG( 0x8d5 )
#define PLX_IOCTL_SERIAL_EEPROM_WRITE           IOCTL_MSG( 0x883 )
#define PLX_IOCTL_SERIAL_EEPROM_WRITE_BY_OFFSET IOCTL_MSG( 0x8d6 )

#define PLX_IOCTL_REGISTER_MAILBOX_READ         IOCTL_MSG( 0x823 )
#define PLX_IOCTL_REGISTER_MAILBOX_WRITE        IOCTL_MSG( 0x824 )
#define PLX_IOCTL_REGISTER_DOORBELL_SERVICE     IOCTL_MSG( 0x825 )
#define PLX_IOCTL_REGISTER_DOORBELL_SET         IOCTL_MSG( 0x826 )

#define PLX_IOCTL_MU_INBOUND_PORT_READ          IOCTL_MSG( 0x870 )
#define PLX_IOCTL_MU_INBOUND_PORT_WRITE         IOCTL_MSG( 0x871 )
#define PLX_IOCTL_MU_OUTBOUND_PORT_READ         IOCTL_MSG( 0x872 )
#define PLX_IOCTL_MU_OUTBOUND_PORT_WRITE        IOCTL_MSG( 0x873 )
#define PLX_IOCTL_MU_OUTINDEX_READ              IOCTL_MSG( 0x8c5 )
#define PLX_IOCTL_MU_OUTINDEX_WRITE             IOCTL_MSG( 0x8c6 )

#define PLX_IOCTL_USER_READ                     IOCTL_MSG( 0x884 )
#define PLX_IOCTL_USER_WRITE                    IOCTL_MSG( 0x885 )

#define PLX_IOCTL_DMA_CONTROL                   IOCTL_MSG( 0x8c0 )
#define PLX_IOCTL_DMA_STATUS                    IOCTL_MSG( 0x8c1 )

#define PLX_IOCTL_DMA_BLOCK_CHANNEL_OPEN        IOCTL_MSG( 0x850 )
#define PLX_IOCTL_DMA_BLOCK_TRANSFER            IOCTL_MSG( 0x852 )
#define PLX_IOCTL_DMA_BLOCK_TRANSFER_RESTART    IOCTL_MSG( 0x853 )
#define PLX_IOCTL_DMA_BLOCK_CHANNEL_CLOSE       IOCTL_MSG( 0x851 )

#define PLX_IOCTL_DMA_SGL_OPEN                  IOCTL_MSG( 0x890 )
#define PLX_IOCTL_DMA_SGL_TRANSFER              IOCTL_MSG( 0x892 )
#define PLX_IOCTL_DMA_SGL_CLOSE                 IOCTL_MSG( 0x891 )

#define PLX_IOCTL_DMA_SHUTTLE_OPEN              IOCTL_MSG( 0x8a0 )
#define PLX_IOCTL_DMA_SHUTTLE_TRANSFER          IOCTL_MSG( 0x8a2 )
#define PLX_IOCTL_DMA_SHUTTLE_CLOSE             IOCTL_MSG( 0x8a1 )

#define PLX_IOCTL_ABORTADDR_READ                IOCTL_MSG( 0x8c7 )



#if 0
/****************************************************************
 * The definition below is left here for future use.  It
 * may eventually be used to ease in numbering of I/O Control
 * messages to the driver.  Due to backwards compatibility,
 * it cannot be implemented at this time
 ***************************************************************/
typdef enum
{
    MSG_DEVICE_INIT,                = 0x800
    MSG_DRIVER_VERSION,
    MSG_CHIP_TYPE_GET,
    MSG_PCI_BOARD_RESET,
    MSG_PCI_DEVICE_FIND,
    MSG_BASE_ADDRESSES_GET,
    MSG_BASE_ADDRESSES_FREE,
    MSG_BAR_RANGE_GET,
    MSG_COMMON_BUFFER_GET,
    MSG_COMMON_BUFFER_FREE,
    MSG_CONFIG_REGISTER_READ,
    MSG_CONFIG_REGISTER_WRITE,
    MSG_CONFIG_REGISTER_READ_ALL,
    MSG_REGISTER_READ,
    MSG_REGISTER_WRITE,
    MSG_REGISTER_READ_ALL,
    MSG_INTR_ENABLE,
    MSG_INTR_DISABLE,
    MSG_INTR_ATTACH,
    MSG_INTR_DETACH,
    MSG_INTR_STATUS_GET,
    MSG_BUS_IOP_READ,
    MSG_BUS_IOP_WRITE,
    MSG_IO_PORT_READ,
    MSG_IO_PORT_WRITE,
    MSG_POWER_LEVEL_SET,
    MSG_POWER_LEVEL_GET,
    MSG_PM_ID_READ,
    MSG_PM_NCP_READ,
    MSG_HS_ID_READ,
    MSG_HS_NCP_READ,
    MSG_HS_STATUS,
    MSG_VPD_ID_READ,
    MSG_VPD_NCP_READ,
    MSG_VPD_READ,
    MSG_VPD_WRITE,
    MSG_EEPROM_PRESENT,
    MSG_SERIAL_EEPROM_READ,
    MSG_SERIAL_EEPROM_READ_BY_OFFSET,
    MSG_SERIAL_EEPROM_WRITE,
    MSG_SERIAL_EEPROM_WRITE_BY_OFFSET,
    MSG_REGISTER_MAILBOX_READ,
    MSG_REGISTER_MAILBOX_WRITE,
    MSG_REGISTER_DOORBELL_SERVICE,
    MSG_REGISTER_DOORBELL_SET,
    MSG_MU_INBOUND_PORT_READ,
    MSG_MU_INBOUND_PORT_WRITE,
    MSG_MU_OUTBOUND_PORT_READ,
    MSG_MU_OUTBOUND_PORT_WRITE,
    MSG_MU_OUTINDEX_READ,
    MSG_MU_OUTINDEX_WRITE,
    MSG_DMA_CONTROL,
    MSG_DMA_STATUS,
    MSG_DMA_BLOCK_CHANNEL_OPEN,
    MSG_DMA_BLOCK_TRANSFER,
    MSG_DMA_BLOCK_TRANSFER_RESTART,
    MSG_DMA_BLOCK_CHANNEL_CLOSE,
    MSG_DMA_SGL_OPEN,
    MSG_DMA_SGL_TRANSFER,
    MSG_DMA_SGL_CLOSE,
    MSG_DMA_SHUTTLE_OPEN,
    MSG_DMA_SHUTTLE_TRANSFER,
    MSG_DMA_SHUTTLE_CLOSE,
    MSG_USER_READ,
    MSG_USER_WRITE,
    MSG_ABORTADDR_READ
}
#endif



#ifdef __cplusplus
}
#endif

#endif
